# Generated by Plain 0.101.0 on 2026-01-18 18:24

from plain import models
from plain.models import migrations


class Migration(migrations.Migration):
    dependencies = [
        (
            "plainpageviews",
            "0004_remove_pageview_plainpageviews_pageview_unique_uuid_and_more",
        ),
    ]

    operations = [
        migrations.AlterField(
            model_name="pageview",
            name="url",
            field=models.URLField(max_length=2048),
        ),
    ]
